/**
 * Instructions to setup an Axeda AMMP profile on the Axeda Console
 *
 * The Axeda-AMMP profile is needed for egress messages to work via the AMMP codec
 * If the Model profile is not created on the Axeda Console and a Model is not configured to use it, this will cause issues with egress (file transfers to the agent, etc)
 *
 * By Martin Tobias 
 * Modifiled by Tim Farlow to remove codec name as a JSON input parameter
 *
 * To Use:
 *    https://[SERVERNAME]/services/v1/rest/Scripto/execute/util_AmmpCreateProfile
 *
 *	The response should be:
 *
 *	{"ok":true,"profileId":"21","profileName":"Polling (axeda-ammp)"}
 *
 *  You will now be able to associate AMMP models with the AMMP Model profile.
 */
import com.axeda.platform.sdk.v1.common.exception.EntityAlreadyExistsException
import com.axeda.platform.sdk.v1.services.ServiceFactory
import com.axeda.platform.sdk.v1.services.modelProfile.DeliveryMethodDescriptor
import com.axeda.platform.sdk.v1.services.modelProfile.ModelProfile
import groovy.json.JsonOutput
import groovy.json.JsonSlurper
import static com.axeda.drm.sdk.scripto.Request.*
//def CODEC_ID_KEY = "codecId"
try {
//    if (!inputStream.available()) {
//        throw new IllegalArgumentException("Expected input, but input was null or empty")
//    }
 
//    def requestData = new JsonSlurper().parse(new InputStreamReader(inputStream))
    def mpService = new ServiceFactory().modelProfileService
    def deliveryMethod = new DeliveryMethodDescriptor(
            codecName           : "awpV1Codec",
            codec2Name          : "",
            deliveryMethodName  : "queueDeliveryMethod",
            transportName       : "",
            maxSize             : 0,
            ordinal             : 0,
            priorityThreshold   : 0,
            timeoutSeconds      : 100,
            maxRetryCount       : 5,
            retryInterval       : 600
    )
	def codecName = "axeda-ammp"
	// codecName = requestData[CODEC_ID_KEY]
    def profileName = "Polling (${codecName})"
    def modelProfile = new ModelProfile(
            profileName: profileName,
            acsCodecName: codecName,
    )
    modelProfile.addDeliveryMethodDescriptor(deliveryMethod)
    def profileId = mpService.create(modelProfile)
 
    return json(ok: true, profileId: profileId?.toString(), profileName: profileName)
}
catch (EntityAlreadyExistsException alreadyExists) {
    logger.error(alreadyExists)
    return json(ok: false, error: [id: 2, reason: alreadyExists.message])
}
catch (any) {
    logger.error(any)
    return json(ok: false, error: [id: 1, reason: any.message])
}
 
def json(data) {
    return ['Content-Type': 'application/json', Content: JsonOutput.toJson(data != null ? data : [:])]
}
